@@ -1,4 +1,4 @@
-from ApiMethod import ApiMethod
+from .ApiMethod import ApiMethod
 from vk_objects import Media
 from typing import List, Dict, Union, Optional
 import time
